@@ -4,13 +4,13 @@ use multer::{Field, Multipart};
 use multimap::MultiMap;
 use std::ffi::OsStr;
 use std::path::{Path, PathBuf};
-use tempdir::TempDir;
+use tempfile::Builder;
 use textnonce::TextNonce;
 use tokio::{fs::File, io::AsyncWriteExt};
 
-use crate::http::errors::ParseError;
 use crate::http::header::{HeaderMap, CONTENT_TYPE};
 use crate::http::request::{self, Body};
+use crate::http::ParseError;
 
 /// The extracted text fields and uploaded files from a `multipart/form-data` request.
 ///
@@ -38,9 +38,6 @@ impl Default for FormData {
         Self::new()
     }
 }
-fn get_extension_from_filename(filename: &str) -> Option<&str> {
-    Path::new(filename).extension().and_then(OsStr::to_str)
-}
 /// A file that is to be inserted into a `multipart/*` or alternatively an uploaded file that
 /// was received as part of `multipart/*` parsing.
 #[derive(Debug)]
@@ -91,7 +88,7 @@ impl FilePart {
     /// deleted once the FilePart object goes out of scope).
     pub async fn create(field: &mut Field<'_>) -> Result<FilePart, ParseError> {
         // Setup a file to capture the contents.
-        let mut path = tokio::task::spawn_blocking(|| TempDir::new("salvo_http_multipart"))
+        let mut path = tokio::task::spawn_blocking(|| Builder::new().prefix("salvo_http_multipart").tempdir())
             .await
             .expect("Runtime spawn blocking poll error")?
             .into_path();
@@ -102,7 +99,7 @@ impl FilePart {
             TextNonce::sized_urlsafe(32).unwrap().into_string(),
             file_name
                 .as_deref()
-                .and_then(get_extension_from_filename)
+                .and_then(|name| { Path::new(name).extension().and_then(OsStr::to_str) })
                 .unwrap_or("unknown")
         ));
         let mut file = File::create(&path).await?;
@@ -131,7 +128,7 @@ impl Drop for FilePart {
     }
 }
 
-/// Parse MIME `multipart/*` information from a stream as a `FormData`.
+/// Parse MIME `multipart/*` information from a stream as a [`FormData`].
 pub(crate) async fn read_form_data(headers: &HeaderMap, body: Body) -> Result<FormData, ParseError> {
     match headers.get(CONTENT_TYPE) {
         Some(ctype) if ctype == "application/x-www-form-urlencoded" => {
