@@ -1,12 +1,4 @@
-// Copyright (c) 2017 Actix Team
-//
-// Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-// http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-// http://opensource.org/licenses/MIT>, at your option. This file may not be
-// copied, modified, or distributed except according to those terms.
-// ported from actix-files
-
-use crate::http::errors::ParseError;
+use crate::http::ParseError;
 
 /// HTTP Range header representation.
 #[derive(Debug, Clone, Copy)]
