@@ -322,7 +322,7 @@ impl Response {
     }
     /// Helper function for get cookie.
     #[inline]
-    pub fn get_cookie<T>(&self, name: T) -> Option<&Cookie<'static>>
+    pub fn cookie<T>(&self, name: T) -> Option<&Cookie<'static>>
     where
         T: AsRef<str>,
     {
@@ -419,11 +419,9 @@ impl Response {
         if let Some(body) = &self.body {
             match body {
                 Body::Bytes(_) => {
-                    tracing::warn!("current body kind is bytes already");
                     return Err(Error::other("current body kind is bytes already"));
                 }
                 Body::Stream(_) => {
-                    tracing::warn!("current body kind is stream already");
                     return Err(Error::other("current body kind is stream already"));
                 }
                 _ => {}
