@@ -1,12 +1,18 @@
-//! The core lib of Savlo web server framework.
-//! Read more: <https://salvo.rs>
+//! The core lib of Savlo web server framework. Read more: <https://salvo.rs>
 #![doc(html_favicon_url = "https://salvo.rs/images/favicon-32x32.png")]
 #![doc(html_logo_url = "https://salvo.rs/images/logo.svg")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
-#![deny(private_in_public, unreachable_pub)]
+#![deny(private_in_public, unreachable_pub, unused_crate_dependencies)]
 #![forbid(unsafe_code)]
 #![warn(missing_docs)]
 
+pub use async_trait::async_trait;
+pub use hyper;
+pub use salvo_macros::fn_handler;
+
+#[macro_use]
+mod cfg;
+
 pub mod addr;
 pub mod catcher;
 mod depot;
@@ -21,11 +27,6 @@ mod service;
 mod transport;
 pub mod writer;
 
-#[cfg(feature = "anyhow")]
-#[cfg_attr(docsrs, doc(cfg(feature = "anyhow")))]
-pub use anyhow;
-pub use hyper;
-
 pub use self::catcher::{Catcher, CatcherImpl};
 pub use self::depot::Depot;
 pub use self::error::Error;
@@ -36,35 +37,38 @@ pub use self::routing::Router;
 pub use self::server::Server;
 pub use self::service::Service;
 pub use self::writer::{Piece, Writer};
-pub use async_trait::async_trait;
-pub use salvo_macros::fn_handler;
 /// Result type wich has salvo::Error as it's error type.
 pub type Result<T> = std::result::Result<T, Error>;
 
 /// A list of things that automatically imports into application use salvo.
 pub mod prelude {
+    pub use async_trait::async_trait;
+    pub use salvo_macros::fn_handler;
+
     pub use crate::depot::Depot;
     pub use crate::http::{Request, Response, StatusCode, StatusError};
-    #[cfg(feature = "acme")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "acme")))]
-    pub use crate::listener::AcmeListener;
-    #[cfg(feature = "rustls")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "rustls")))]
-    pub use crate::listener::RustlsListener;
-    #[cfg(unix)]
-    #[cfg_attr(docsrs, doc(cfg(unix)))]
-    pub use crate::listener::UnixListener;
+    cfg_feature! {
+        #![feature ="acme"]
+        pub use crate::listener::AcmeListener;
+    }
+    cfg_feature! {
+        #![feature ="rustls"]
+        pub use crate::listener::RustlsListener;
+    }
+    cfg_feature! {
+        #![unix]
+        pub use crate::listener::UnixListener;
+    }
     pub use crate::listener::{JoinedListener, Listener, TcpListener};
     pub use crate::routing::{FlowCtrl, Router};
     pub use crate::server::Server;
     pub use crate::service::Service;
     pub use crate::writer::{Json, Piece, Text, Writer};
     pub use crate::Handler;
-    pub use async_trait::async_trait;
-    pub use salvo_macros::fn_handler;
 }
 
-use std::future::Future;
+use std::{future::Future, thread::available_parallelism};
+
 use tokio::runtime::{self, Runtime};
 
 fn new_runtime(threads: usize) -> Runtime {
@@ -78,34 +82,43 @@ fn new_runtime(threads: usize) -> Runtime {
 
 /// If you don't want to include tokio in your project directly,
 /// you can use this function to run server.
-/// ```ignore
-/// use salvo_core::prelude::*;
+///
+/// # Example
+///
+/// ```no_run
+/// # use salvo_core::prelude::*;
+///
 /// #[fn_handler]
 /// async fn hello_world() -> &'static str {
 ///     "Hello World"
 /// }
-/// fn main() {
-///
+/// #[tokio::main]
+/// async fn main() {
 ///    let router = Router::new().get(hello_world);
 ///    let server = Server::new(TcpListener::bind("127.0.0.1:7878")).serve(router);
 ///    salvo_core::run(server);
 /// }
 /// ```
 pub fn run<F: Future>(future: F) {
-    run_with_threads(future, num_cpus::get())
+    run_with_threads(future, available_parallelism().map(|n| n.get()).unwrap_or(1))
 }
 
 /// If you don't want to include tokio in your project directly,
 /// you can use this function to run server.
-/// ```ignore
+///
+/// # Example
+///
+/// ```no_run
 /// use salvo_core::prelude::*;
+///
 /// #[fn_handler]
 /// async fn hello_world() -> &'static str {
 ///     "Hello World"
 /// }
+///
 /// fn main() {
-///    let service = Router::new().get(hello_world);
-///    let server = Server::new(TcpListener::bind("127.0.0.1:7878")).serve(router).await;
+///    let router = Router::new().get(hello_world);
+///    let server = Server::new(TcpListener::bind("127.0.0.1:7878")).serve(router);
 ///    salvo_core::run_with_threads(server, 8);
 /// }
 /// ```
