@@ -2,6 +2,63 @@
 //!
 //! Reference: <https://datatracker.ietf.org/doc/html/rfc8555>
 //! Reference: <https://datatracker.ietf.org/doc/html/rfc8737>
+//! 
+//! * HTTP-01
+//! 
+//! # Example
+//! 
+//! ```no_run
+//! use salvo_core::listener::{AcmeListener, TcpListener};
+//! use salvo_core::prelude::*;
+//! 
+//! #[fn_handler]
+//! async fn hello_world() -> &'static str {
+//!     "Hello World"
+//! }
+//! 
+//! #[tokio::main]
+//! async fn main() {
+//!     let mut router = Router::new().get(hello_world);
+//!     let listener = AcmeListener::builder()
+//!         // .directory("letsencrypt", salvo::listener::acme::LETS_ENCRYPT_STAGING)
+//!         .cache_path("acme/letsencrypt")
+//!         .add_domain("acme-http01.salvo.rs")
+//!         .http01_challege(&mut router)
+//!         .bind("0.0.0.0:443")
+//!         .await;
+//!     tracing::info!("Listening on https://0.0.0.0:443");
+//!     Server::new(listener.join(TcpListener::bind("0.0.0.0:80")))
+//!         .serve(router)
+//!         .await;
+//! }
+//! ```
+//! 
+//! * TLS ALPN-01
+//! 
+//! # Example
+//! 
+//! ```no_run
+//! use salvo_core::listener::AcmeListener;
+//! use salvo_core::prelude::*;
+//! 
+//! #[fn_handler]
+//! async fn hello_world() -> &'static str {
+//!     "Hello World"
+//! }
+//! 
+//! #[tokio::main]
+//! async fn main() {
+//!     let router = Router::new().get(hello_world);
+//!     let listener = AcmeListener::builder()
+//!         // .directory("letsencrypt", salvo::listener::acme::LETS_ENCRYPT_STAGING)
+//!         .cache_path("acme/letsencrypt")
+//!         .add_domain("acme-tls-alpn01.salvo.rs")
+//!         .bind("0.0.0.0:443")
+//!         .await;
+//!     tracing::info!("Listening on https://0.0.0.0:443");
+//!     Server::new(listener).serve(router).await;
+//! }
+//! ```
 
 pub mod cache;
 mod client;
@@ -35,7 +92,7 @@ use tokio_rustls::rustls::sign::{any_ecdsa_type, CertifiedKey};
 use tokio_rustls::rustls::PrivateKey;
 
 use crate::addr::SocketAddr;
-use crate::http::errors::StatusError;
+use crate::http::StatusError;
 use crate::listener::{IntoAddrIncoming, Listener};
 use crate::routing::FlowCtrl;
 use crate::transport::Transport;
@@ -161,7 +218,7 @@ impl AcmeListenerBuilder {
     ///
     /// Defaults to lets encrypt.
     #[inline]
-    pub fn directory(self, name: impl Into<String>, url: impl Into<String>) -> Self {
+    pub fn get_directory(self, name: impl Into<String>, url: impl Into<String>) -> Self {
         Self {
             config_builder: self.config_builder.directory(name, url),
             ..self
