@@ -1,16 +1,15 @@
-//! Writer trait and it's impls.
+//! Writer trait and it's implements.
 use async_trait::async_trait;
 use serde::Serialize;
 
-use crate::http::errors::*;
 use crate::http::header::{HeaderValue, CONTENT_TYPE};
-use crate::http::{Request, Response};
+use crate::http::{Request, Response, StatusError};
 use crate::Depot;
 
 /// Writer is used to write data to response.
 #[async_trait]
 pub trait Writer {
-    /// Write data to ```Respone```.
+    /// Write data to [`Response`].
     #[must_use = "write future must be used"]
     async fn write(mut self, req: &mut Request, depot: &mut Depot, res: &mut Response);
 }
@@ -33,9 +32,11 @@ where
     }
 }
 
-/// Piece is used to write data to response.
+/// `Piece` is used to write data to [`Response`].
+///
+/// `Piece` is simpler than [`Writer`] ant it implements [`Writer`].
 pub trait Piece {
-    /// Render data to ```Respone```.
+    /// Render data to [`Response`].
     fn render(self, res: &mut Response);
 }
 #[async_trait]
@@ -148,7 +149,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_write_str() {
-        #[fn_handler]
+        #[fn_handler(internal)]
         async fn test() -> &'static str {
             "hello"
         }
@@ -163,7 +164,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_write_string() {
-        #[fn_handler]
+        #[fn_handler(internal)]
         async fn test() -> String {
             "hello".to_owned()
         }
@@ -178,7 +179,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_write_plain_text() {
-        #[fn_handler]
+        #[fn_handler(internal)]
         async fn test() -> Text<&'static str> {
             Text::Plain("hello")
         }
@@ -193,7 +194,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_write_json_text() {
-        #[fn_handler]
+        #[fn_handler(internal)]
         async fn test() -> Text<&'static str> {
             Text::Json(r#"{"hello": "world"}"#)
         }
@@ -215,7 +216,7 @@ mod tests {
         struct User {
             name: String,
         }
-        #[fn_handler]
+        #[fn_handler(internal)]
         async fn test() -> Json<User> {
             Json(User { name: "jobs".into() })
         }
@@ -233,7 +234,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_write_html_text() {
-        #[fn_handler]
+        #[fn_handler(internal)]
         async fn test() -> Text<&'static str> {
             Text::Html("<html><body>hello</body></html>")
         }
